@@ -54,6 +54,7 @@ glue_solve_gen::apply(Mat<eT>& out, const Base<eT,T1>& A_expr, const Base<eT,T2>
   const bool no_approx   = bool(flags & solve_opts::flag_no_approx  );
   const bool no_band     = bool(flags & solve_opts::flag_no_band    );
   const bool no_sympd    = bool(flags & solve_opts::flag_no_sympd   );
+  const bool allow_ugly  = bool(flags & solve_opts::flag_allow_ugly );
   
   arma_extra_debug_print("glue_solve_gen::apply(): enabled flags:");
   
@@ -62,6 +63,7 @@ glue_solve_gen::apply(Mat<eT>& out, const Base<eT,T1>& A_expr, const Base<eT,T2>
   if(no_approx  )  { arma_extra_debug_print("no_approx");   }
   if(no_band    )  { arma_extra_debug_print("no_band");     }
   if(no_sympd   )  { arma_extra_debug_print("no_sympd");    }
+  if(allow_ugly )  { arma_extra_debug_print("allow_ugly");  }
   
   arma_debug_check( (fast && equilibrate), "solve(): options 'fast' and 'equilibrate' are mutually exclusive" );
   
@@ -84,9 +86,9 @@ glue_solve_gen::apply(Mat<eT>& out, const Base<eT,T1>& A_expr, const Base<eT,T2>
     #endif
     
     #if defined(ARMA_OPTIMISE_SOLVE_SYMPD)
-      const bool is_sympd = ((no_sympd == false) && (auxlib::crippled_lapack(A) == false) && (is_band == false)) ? sympd_helper::guess_sympd(A) : false;
+      const bool try_sympd = ((no_sympd == false) && (auxlib::crippled_lapack(A) == false) && (is_band == false)) ? sympd_helper::guess_sympd(A) : false;
     #else
-      const bool is_sympd = false;
+      const bool try_sympd = false;
     #endif
     
     if(fast)
@@ -107,9 +109,9 @@ glue_solve_gen::apply(Mat<eT>& out, const Base<eT,T1>& A_expr, const Base<eT,T2>
           }
         }
       else
-      if(is_sympd)
+      if(try_sympd)
         {
-        arma_extra_debug_print("glue_solve_gen::apply(): fast + sympd");
+        arma_extra_debug_print("glue_solve_gen::apply(): fast + try_sympd");
         
         status = auxlib::solve_sympd_fast(out, A, B_expr.get_ref());  // A is overwritten
         
@@ -137,21 +139,21 @@ glue_solve_gen::apply(Mat<eT>& out, const Base<eT,T1>& A_expr, const Base<eT,T2>
           {
           arma_extra_debug_print("glue_solve_gen::apply(): refine + tridiagonal");
           
-          status = auxlib::solve_tridiag_refine(out, rcond, A, B_expr);
+          status = auxlib::solve_tridiag_refine(out, rcond, A, B_expr, allow_ugly);
           }
         else
           {
           arma_extra_debug_print("glue_solve_gen::apply(): refine + band");
           
-          status = auxlib::solve_band_refine(out, rcond, A, KL, KU, B_expr, equilibrate);
+          status = auxlib::solve_band_refine(out, rcond, A, KL, KU, B_expr, equilibrate, allow_ugly);
           }
         }
       else
-      if(is_sympd)
+      if(try_sympd)
         {
-        arma_extra_debug_print("glue_solve_gen::apply(): refine + sympd");
+        arma_extra_debug_print("glue_solve_gen::apply(): refine + try_sympd");
         
-        status = auxlib::solve_sympd_refine(out, rcond, A, B_expr.get_ref(), equilibrate);  // A is overwritten
+        status = auxlib::solve_sympd_refine(out, rcond, A, B_expr.get_ref(), equilibrate, allow_ugly);  // A is overwritten
         
         if(status == false)
           {
@@ -159,30 +161,22 @@ glue_solve_gen::apply(Mat<eT>& out, const Base<eT,T1>& A_expr, const Base<eT,T2>
           
           // auxlib::solve_sympd_refine() may have failed because A isn't really sympd
           A = A_expr.get_ref();
-          status = auxlib::solve_square_refine(out, rcond, A, B_expr.get_ref(), equilibrate);  // A is overwritten
+          status = auxlib::solve_square_refine(out, rcond, A, B_expr.get_ref(), equilibrate, allow_ugly);  // A is overwritten
           }
         }
       else
         {
         arma_extra_debug_print("glue_solve_gen::apply(): refine + dense");
         
-        status = auxlib::solve_square_refine(out, rcond, A, B_expr, equilibrate);  // A is overwritten
+        status = auxlib::solve_square_refine(out, rcond, A, B_expr, equilibrate, allow_ugly);  // A is overwritten
         }
       }
     
     
-      // if((status == true) && (rcond > T(0)) && (rcond <= (T(0.5)*std::numeric_limits<T>::epsilon())) )
-      //   {
-      //   // arma_debug_warn("solve(): system seems singular to working precision (rcond: ", rcond, ")");
-      //   
-      //   status = approx_equal( A_expr.get_ref() * out, B_expr.get_ref(), "reldiff", T(2)*std::numeric_limits<T>::epsilon() );
-      //   
-      //   if(status == true)
-      //     {
-      //     // solution seems okay, but warn the user about rcond
-      //     arma_debug_warn("solve(): system seems singular to working precision (rcond: ", rcond, ")");
-      //     }
-      //   }
+    if( (status == true) && (rcond > T(0)) && (rcond <= (T(0.5)*std::numeric_limits<T>::epsilon())) )
+      {
+      arma_debug_warn("solve(): solution computed, but system seems singular to working precision (rcond: ", rcond, ")");
+      }
     
     
     if( (status == false) && (no_approx == false) )
